@@ -1,5 +1,5 @@
 package Win32::Exe;
-$Win32::Exe::VERSION = '0.14';
+$Win32::Exe::VERSION = '0.15';
 
 =head1 NAME
 
@@ -7,8 +7,8 @@ Win32::Exe - Manipulate Win32 executable files
 
 =head1 VERSION
 
-This document describes version 0.14 of Win32::Exe, released
-May 03, 2010.
+This document describes version 0.15 of Win32::Exe, released
+November 10, 2010.
 
 =head1 SYNOPSIS
 
