@@ -2,7 +2,7 @@
 # Package       Win32::Exe::Manifest::Parser
 # Description:  XML Parser for Manifests
 # Created       Wed Apr 21 07:54:51 2010
-# SVN Id        $Id:$
+# SVN Id        $Id: Parser.pm 2 2010-04-30 13:09:56Z  $
 # Copyright:    Copyright (c) 2010 Mark Dootson
 # Licence:      This program is free software; you can redistribute it 
 #               and/or modify it under the same terms as Perl itself
@@ -18,7 +18,7 @@ use XML::Simple 2.18;
 use base qw( XML::Simple );
 use Carp;
 
-our $VERSION = '0.13';
+our $VERSION = '0.15';
 
 =head1 NAME
 
@@ -26,8 +26,8 @@ Win32::Exe::Manifest::Parser - MSWin Application and Assembly manifest handling
 
 =head1 VERSION
 
-This document describes version 0.13 of Win32::Exe::Manifest::Parser, released
-April 28, 2010. 
+This document describes version 0.15 of Win32::Exe::Manifest::Parser, released
+November 30, 2010. 
 
 =head1 DESCRIPTION
 
